@@ -133,8 +133,7 @@ void KQuery::start()
             job = KIO::listDir(m_url, KIO::HideProgressInfo);
         }
 
-        connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
-                SLOT(slotListEntries(KIO::Job*,KIO::UDSEntryList)));
+        connect(job, &KIO::ListJob::entries, this, QOverload<KIO::Job*, const KIO::UDSEntryList&>::of(&KQuery::slotListEntries));
         connect(job, &KIO::ListJob::result, this, &KQuery::slotResult);
     }
 }
@@ -208,7 +207,7 @@ void KQuery::checkEntries()
 }
 
 /* List of files found using slocate */
-void KQuery::slotListEntries(QStringList list)
+void KQuery::slotListEntries(const QStringList &list)
 {
     metaKeyRx = QRegExp(m_metainfokey);
     metaKeyRx.setPatternSyntax(QRegExp::Wildcard);
@@ -598,7 +597,7 @@ void KQuery::setShowHiddenFiles(bool showHidden)
 
 void KQuery::slotreadyReadStandardError()
 {
-    KMessageBox::error(NULL, QString::fromLocal8Bit(processLocate->readAllStandardOutput()), i18nc("@title:window", "Error while using locate"));
+    KMessageBox::error(nullptr, QString::fromLocal8Bit(processLocate->readAllStandardOutput()), i18nc("@title:window", "Error while using locate"));
 }
 
 void KQuery::slotreadyReadStandardOutput()
